@@ -13,23 +13,21 @@ def main():
 
     Currently the CLI can read any pyGAPS format (JSON, CSV, Excel) and then:
 
-        * print isotherm to output (default if no argument is passed)
-        * plot the isotherm using a Matplotlib window (``-p/--plot``)
-        * run basic automated characterization tests (``-ch/--characterize a_bet``
-          for the BET area for example)
-        * attempt to model the isotherm using a requested model or guess the best
-          fitting model (``-md/--model guess``) and save the resulting isotherm model
-          using the ``-o/--outfile`` path.
-        * convert the isotherm to any unit/basis
-          (``-cv/--convert pressure_mode=absolute,pressure_unit=bar``) and save the
-          resulting isotherm model using the ``-o/--outfile`` path.
+    * print isotherm to output (default if no argument is passed)
+    * plot the isotherm using a Matplotlib window (``-p/--plot``)
+    * run basic automated characterization tests (``-ch/--characterize a_bet``
+      for the BET area for example)
+    * attempt to model the isotherm using a requested model or guess the best
+      fitting model (``-md/--model guess``) and save the resulting isotherm
+      model using the ``-o/--outfile`` path.
+    * convert the isotherm to any unit/basis
+      (``-cv/--convert pressure_mode=absolute,pressure_unit=bar``) and save the
+      resulting isotherm model using the ``-o/--outfile`` path.
 
     """
 
     # Create the parser
-    prs = argparse.ArgumentParser(
-        description='Command-line interface to pyGAPS'
-    )
+    prs = argparse.ArgumentParser(description='Command-line interface to pyGAPS')
 
     # Add the arguments
     prs.add_argument(
@@ -77,21 +75,21 @@ def main():
     # Execute the parse_args() method
     args = prs.parse_args()
 
-    import pygaps as pg
-
     # Read the isotherm
     if not args.iso.exists():
         raise FileNotFoundError("Path does not exist.")
 
+    import pygaps.parsing as pgp
+
     ext = args.iso.suffix
     if ext == '.json':
-        iso = pg.isotherm_from_json(args.iso)
+        iso = pgp.isotherm_from_json(args.iso)
     elif ext == '.csv':
-        iso = pg.isotherm_from_csv(args.iso)
+        iso = pgp.isotherm_from_csv(args.iso)
     elif ext == '.xls':
-        iso = pg.isotherm_from_xl(args.iso)
+        iso = pgp.isotherm_from_xl(args.iso)
     elif ext == '.aif':
-        iso = pg.isotherm_from_aif(args.iso)
+        iso = pgp.isotherm_from_aif(args.iso)
     else:
         from pygaps.utilities.exceptions import ParsingError
         raise ParsingError(f"Cannot read '{ext}' files")
@@ -101,19 +99,21 @@ def main():
 
     # pass to various characterization functions
     if args.characterize:
+        import pygaps.characterisation as pgc
         plot = args.verbose
         if args.characterize == 'a_bet':
-            res = pg.area_BET(iso, verbose=args.verbose)
+            res = pgc.area_BET(iso, verbose=args.verbose)
             print(res)
         elif args.characterize == 'a_lang':
-            res = pg.area_langmuir(iso, verbose=args.verbose)
+            res = pgc.area_langmuir(iso, verbose=args.verbose)
         elif args.characterize == 'kh':
-            res = pg.initial_henry_slope(iso, verbose=args.verbose)
+            res = pgc.initial_henry_slope(iso, verbose=args.verbose)
 
     # model isotherm using `model_iso`
     elif args.model:
+        import pygaps.modelling as pgm
         plot = args.verbose
-        out_iso = pg.model_iso(iso, model=args.model, verbose=args.verbose)
+        out_iso = pgm.model_iso(iso, model=args.model, verbose=args.verbose)
 
     # convert an isotherm to a different basis/unit
     elif args.convert:
